pub struct DCKeywordList {
keywords: Vec<DCKeyword>,
}Expand description
This is a list of DCKeyword structures, which represent
communication keywords that may be set on a particular field.
Fields
keywords: Vec<DCKeyword>Implementations
Sourceimpl DCKeywordList
impl DCKeywordList
Sourcepub fn get_num_keywords(&self) -> usize
pub fn get_num_keywords(&self) -> usize
Returns the number of keywords in this keyword list.
Sourcepub fn has_keyword(&self, kw: IdentifyKeyword) -> bool
pub fn has_keyword(&self, kw: IdentifyKeyword) -> bool
Returns true if given keyword identifier or struct
is present in this keyword list.